@@ -1,6 +1,6 @@
 // Descriptor wallet library extending bitcoin & miniscript functionality
 // by LNP/BP Association (https://lnp-bp.org)
-// Written in 2020-2021 by
+// Written in 2020-2022 by
 //     Dr. Maxim Orlovsky <orlovsky@pandoracore.com>
 //
 // To the extent possible under law, the author(s) have dedicated all
@@ -20,16 +20,23 @@
 
 #[macro_use]
 extern crate amplify;
+#[cfg(feature = "miniscript")]
+extern crate miniscript_crate as miniscript;
 
+#[cfg(feature = "miniscript")]
+pub mod construct;
+#[cfg(feature = "miniscript")]
+mod deduction;
+pub mod lex_order;
 mod proprietary;
-mod signer;
-mod structure;
+pub mod sign;
+mod util;
+
 pub use bitcoin::util::psbt::raw::{ProprietaryKey, ProprietaryType};
 pub use bitcoin::util::psbt::{
-    raw, Error, Global, Input, Map, Output, PartiallySignedTransaction as Psbt,
+    raw, Error, Input, Output, PartiallySignedTransaction as Psbt, PsbtParseError,
 };
-pub use proprietary::{
-    ProprietaryWalletInput, PSBT_WALLET_IN_TWEAK, PSBT_WALLET_PREFIX,
-};
-pub use signer::{Signer, SigningError};
-pub use structure::{Fee, FeeError, InputPreviousTxo, MatchError};
+#[cfg(feature = "miniscript")]
+pub use deduction::{DeductionError, InputDeduce};
+pub use proprietary::{InputP2cTweak, PSBT_IN_P2C_TWEAK, PSBT_P2C_PREFIX};
+pub use util::{Fee, FeeError, InputMatchError, InputPrevout, Tx};
